@@ -82,8 +82,8 @@ class Word:
     def copy(self):
         return Word(
             word=self.word,
-            start_time_millis=self.start_time*1000,
-            end_time_millis=self.end_time*1000,
+            start_time_millis=self.start_time,
+            end_time_millis=self.end_time,
             speaker=self.speaker,
             confidence=self.confidence
         )
