@@ -17,8 +17,12 @@ class TranscriptionResponseFormat(Enum):
 
 
 class TranscriptionRequest:
-    def __init__(self, file_uid: str, file_path: Union[str, Path], model: Model, success_url: Optional[str] = None,
-                 fail_url: Optional[str] = None, hotwords: Optional[Union[list, str]] = None,
+    def __init__(self, file_uid: str,
+                 file_path: Union[str, Path],
+                 model: Model,
+                 success_url: Optional[str] = None,
+                 fail_url: Optional[str] = None,
+                 hotwords: Optional[Union[list, str]] = None,
                  hotwords_weight: Optional[float] = None,
                  transcript_format: TranscriptionResponseFormat = TranscriptionResponseFormat.JSON,
                  file_duration: Optional[float] = None,
@@ -63,7 +67,8 @@ class TranscriptionRequest:
 
 class TranscriptionResponse:
 
-    def __init__(self, transcript: List[Word], headers: Dict[str, Any], request: TranscriptionRequest):
+    def __init__(self, transcript: List[Word], headers: Dict[str, Any], request: TranscriptionRequest,
+                 processed_transcript: Optional[List[Word]] = None):
         assert transcript is not None
         assert request is not None
 
@@ -71,5 +76,6 @@ class TranscriptionResponse:
             headers = {}
 
         self.transcript: List[Word] = transcript
+        self.processed_transcript: Optional[List[Word]] = processed_transcript
         self.headers: Dict[str, Any] = headers
         self.request: TranscriptionRequest = request
